[telepathy-qt4/master] Renamed RoomList to RoomListChannel.

Andre Moreira Magalhaes (andrunko) andre.magalhaes at collabora.co.uk
Wed Jul 22 22:04:56 PDT 2009


---
 TelepathyQt4/Makefile.am                           |    8 +++---
 TelepathyQt4/RoomList                              |   13 ---------
 TelepathyQt4/RoomListChannel                       |   13 +++++++++
 TelepathyQt4/channel-factory.cpp                   |    4 +-
 TelepathyQt4/pending-channel.cpp                   |    4 ---
 .../{room-list.cpp => room-list-channel.cpp}       |   28 ++++++++++----------
 TelepathyQt4/{room-list.h => room-list-channel.h}  |   16 +++++-----
 TelepathyQt4/types.h                               |    4 +-
 8 files changed, 43 insertions(+), 47 deletions(-)
 delete mode 100644 TelepathyQt4/RoomList
 create mode 100644 TelepathyQt4/RoomListChannel
 rename TelepathyQt4/{room-list.cpp => room-list-channel.cpp} (72%)
 rename TelepathyQt4/{room-list.h => room-list-channel.h} (74%)

diff --git a/TelepathyQt4/Makefile.am b/TelepathyQt4/Makefile.am
index ea385e1..879fd59 100644
--- a/TelepathyQt4/Makefile.am
+++ b/TelepathyQt4/Makefile.am
@@ -94,7 +94,7 @@ libtelepathy_qt4_la_SOURCES = \
     readiness-helper.cpp \
     ready-object.cpp \
     referenced-handles.cpp \
-    room-list.cpp \
+    room-list-channel.cpp \
     streamed-media-channel.cpp \
     text-channel.cpp \
     types.cpp
@@ -156,7 +156,7 @@ nodist_libtelepathy_qt4_la_SOURCES = \
     _gen/pending-ready.moc.hpp \
     _gen/pending-string-list.moc.hpp \
     _gen/readiness-helper.moc.hpp \
-    _gen/room-list.moc.hpp \
+    _gen/room-list-channel.moc.hpp \
     _gen/simple-pending-operations.moc.hpp \
     _gen/streamed-media-channel.moc.hpp \
     _gen/text-channel.moc.hpp
@@ -212,7 +212,7 @@ tpqt4include_HEADERS = \
     RefCounted \
     ReferencedHandles \
     ReferencedHandlesIterator \
-    RoomList \
+    RoomListChannel \
     SharedPtr \
     StatelessDBusProxy \
     StatefulDBusProxy \
@@ -300,7 +300,7 @@ tpqt4include_HEADERS = \
     readiness-helper.h \
     ready-object.h \
     referenced-handles.h \
-    room-list.h \
+    room-list-channel.h \
     shared-ptr.h \
     simple-pending-operations.h \
     streamed-media-channel.h \
diff --git a/TelepathyQt4/RoomList b/TelepathyQt4/RoomList
deleted file mode 100644
index 1552461..0000000
--- a/TelepathyQt4/RoomList
+++ /dev/null
@@ -1,13 +0,0 @@
-#ifndef _TelepathyQt4_Client_RoomList_HEADER_GUARD_
-#define _TelepathyQt4_Client_RoomList_HEADER_GUARD_
-
-#ifndef IN_TELEPATHY_QT4_HEADER
-#define IN_TELEPATHY_QT4_HEADER
-#endif
-
-#include <TelepathyQt4/room-list.h>
-
-#undef IN_TELEPATHY_QT4_HEADER
-
-#endif
-// vim:set ft=cpp:
diff --git a/TelepathyQt4/RoomListChannel b/TelepathyQt4/RoomListChannel
new file mode 100644
index 0000000..cfaf82e
--- /dev/null
+++ b/TelepathyQt4/RoomListChannel
@@ -0,0 +1,13 @@
+#ifndef _TelepathyQt4_Client_RoomListChannel_HEADER_GUARD_
+#define _TelepathyQt4_Client_RoomListChannel_HEADER_GUARD_
+
+#ifndef IN_TELEPATHY_QT4_HEADER
+#define IN_TELEPATHY_QT4_HEADER
+#endif
+
+#include <TelepathyQt4/room-list-channel.h>
+
+#undef IN_TELEPATHY_QT4_HEADER
+
+#endif
+// vim:set ft=cpp:
diff --git a/TelepathyQt4/channel-factory.cpp b/TelepathyQt4/channel-factory.cpp
index b4b8399..9a356cb 100644
--- a/TelepathyQt4/channel-factory.cpp
+++ b/TelepathyQt4/channel-factory.cpp
@@ -25,7 +25,7 @@
 #include <TelepathyQt4/Connection>
 #include <TelepathyQt4/Constants>
 #include <TelepathyQt4/FileTransfer>
-#include <TelepathyQt4/RoomList>
+#include <TelepathyQt4/RoomListChannel>
 #include <TelepathyQt4/StreamedMediaChannel>
 #include <TelepathyQt4/TextChannel>
 
@@ -49,7 +49,7 @@ ChannelPtr ChannelFactory::create(const ConnectionPtr &connection,
     }
     else if (channelType == TELEPATHY_INTERFACE_CHANNEL_TYPE_ROOM_LIST) {
         return ChannelPtr(dynamic_cast<Channel*>(
-                    RoomList::create(connection,
+                    RoomListChannel::create(connection,
                         channelPath, immutableProperties).data()));
     }
     else if (channelType == TELEPATHY_INTERFACE_CHANNEL_TYPE_FILE_TRANSFER) {
diff --git a/TelepathyQt4/pending-channel.cpp b/TelepathyQt4/pending-channel.cpp
index 285dc29..6a5844a 100644
--- a/TelepathyQt4/pending-channel.cpp
+++ b/TelepathyQt4/pending-channel.cpp
@@ -28,10 +28,6 @@
 
 #include <TelepathyQt4/Channel>
 #include <TelepathyQt4/Connection>
-#include <TelepathyQt4/FileTransfer>
-#include <TelepathyQt4/RoomList>
-#include <TelepathyQt4/StreamedMediaChannel>
-#include <TelepathyQt4/TextChannel>
 #include <TelepathyQt4/Constants>
 
 /**
diff --git a/TelepathyQt4/types.h b/TelepathyQt4/types.h
index 9657388..92160f4 100644
--- a/TelepathyQt4/types.h
+++ b/TelepathyQt4/types.h
@@ -45,7 +45,7 @@ class ClientRegistrar;
 class Connection;
 class ConnectionManager;
 class FileTransfer;
-class RoomList;
+class RoomListChannel;
 class MediaStream;
 class StreamedMediaChannel;
 class TextChannel;
@@ -61,7 +61,7 @@ typedef SharedPtr<ClientRegistrar> ClientRegistrarPtr;
 typedef SharedPtr<Connection> ConnectionPtr;
 typedef SharedPtr<ConnectionManager> ConnectionManagerPtr;
 typedef SharedPtr<FileTransfer> FileTransferPtr;
-typedef SharedPtr<RoomList> RoomListPtr;
+typedef SharedPtr<RoomListChannel> RoomListChannelPtr;
 typedef SharedPtr<MediaStream> MediaStreamPtr;
 typedef SharedPtr<StreamedMediaChannel> StreamedMediaChannelPtr;
 typedef SharedPtr<TextChannel> TextChannelPtr;
diff --git a/TelepathyQt4/room-list.cpp b/TelepathyQt4/room-list-channel.cpp
similarity index 72%
rename from TelepathyQt4/room-list.cpp
rename to TelepathyQt4/room-list-channel.cpp
index d2bb358..2e34895 100644
--- a/TelepathyQt4/room-list.cpp
+++ b/TelepathyQt4/room-list-channel.cpp
@@ -1,4 +1,4 @@
 /* RoomList channel client-side proxy
  *
  * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
  * Copyright (C) 2009 Nokia Corporation
@@ -18,9 +18,9 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <TelepathyQt4/RoomList>
+#include <TelepathyQt4/RoomListChannel>
 
-#include "TelepathyQt4/_gen/room-list.moc.hpp"
+#include "TelepathyQt4/_gen/room-list-channel.moc.hpp"
 #include "TelepathyQt4/debug-internal.h"
 
 #include <TelepathyQt4/Connection>
@@ -28,24 +28,24 @@
 namespace Tp
 {
 
-struct RoomList::Private
+struct RoomListChannel::Private
 {
     inline Private();
     inline ~Private();
 };
 
-RoomList::Private::Private()
+RoomListChannel::Private::Private()
 {
 }
 
-RoomList::Private::~Private()
+RoomListChannel::Private::~Private()
 {
 }
 
 /**
- * \class RoomList
+ * \class RoomListChannel
  * \ingroup clientchannel
- * \headerfile TelepathyQt4/room-list.h <TelepathyQt4/RoomList>
+ * \headerfile TelepathyQt4/room-list-channel.h <TelepathyQt4/RoomListChannel>
  *
  * High-level proxy object for accessing remote %Channel objects of the RoomList
  * channel type.
@@ -54,25 +54,25 @@ RoomList::Private::~Private()
  * RoomList interface. Until then, it's just a Channel.
  */
 
-RoomListPtr RoomList::create(const ConnectionPtr &connection,
+RoomListChannelPtr RoomListChannel::create(const ConnectionPtr &connection,
         const QString &objectPath, const QVariantMap &immutableProperties)
 {
-    return RoomListPtr(new RoomList(connection, objectPath,
+    return RoomListChannelPtr(new RoomListChannel(connection, objectPath,
                 immutableProperties));
 }
 
 /**
  * Creates a RoomList associated with the given object on the same service
  * as the given connection.
  *
  * \param connection  Connection owning this RoomList, and specifying the
  *                    service.
  * \param objectPath  Path to the object on the service.
  * \param immutableProperties  The immutable properties of the channel, as
  *                             signalled by NewChannels or returned by
  *                             CreateChannel or EnsureChannel
  */
-RoomList::RoomList(const ConnectionPtr &connection,
+RoomListChannel::RoomListChannel(const ConnectionPtr &connection,
         const QString &objectPath,
         const QVariantMap &immutableProperties)
     : Channel(connection, objectPath, immutableProperties),
@@ -83,7 +83,7 @@ RoomList::RoomList(const ConnectionPtr &connection,
 /**
  * Class destructor.
  */
-RoomList::~RoomList()
+RoomListChannel::~RoomListChannel()
 {
     delete mPriv;
 }
@@ -1,4 +1,4 @@
-/* RoomList channel client-side proxy
+/* RoomListChannel channel client-side proxy
  *
  * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
@@ -54,25 +54,25 @@ RoomList::Private::~Private()
 
 /**
- * Creates a RoomList associated with the given object on the same service
+ * Creates a RoomListChannel associated with the given object on the same service
  * as the given connection.
  *
@@ -54,25 +54,25 @@ RoomList::Private::~Private()
  * as the given connection.
  *
- * \param connection  Connection owning this RoomList, and specifying the
+ * \param connection  Connection owning this RoomListChannel, and specifying the
  *                    service.
  * \param objectPath  Path to the object on the service.
diff --git a/TelepathyQt4/room-list.h b/TelepathyQt4/room-list-channel.h
similarity index 74%
rename from TelepathyQt4/room-list.h
rename to TelepathyQt4/room-list-channel.h
index ea9ac9f..53404e3 100644
--- a/TelepathyQt4/room-list.h
+++ b/TelepathyQt4/room-list-channel.h
@@ -1,4 +1,4 @@
 /* RoomList channel client-side proxy
  *
  * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
  * Copyright (C) 2009 Nokia Corporation
@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef _TelepathyQt4_Client_room_list_h_HEADER_GUARD_
-#define _TelepathyQt4_Client_room_list_h_HEADER_GUARD_
+#ifndef _TelepathyQt4_Client_room_list_channel_h_HEADER_GUARD_
+#define _TelepathyQt4_Client_room_list_channel_h_HEADER_GUARD_
 
 #ifndef IN_TELEPATHY_QT4_HEADER
 #error IN_TELEPATHY_QT4_HEADER
@@ -30,19 +30,19 @@
 namespace Tp
 {
 
-class RoomList : public Channel
+class RoomListChannel : public Channel
 {
     Q_OBJECT
-    Q_DISABLE_COPY(RoomList)
+    Q_DISABLE_COPY(RoomListChannel)
 
 public:
-    static RoomListPtr create(const ConnectionPtr &connection,
+    static RoomListChannelPtr create(const ConnectionPtr &connection,
             const QString &objectPath, const QVariantMap &immutableProperties);
 
-    virtual ~RoomList();
+    virtual ~RoomListChannel();
 
 protected:
-    RoomList(const ConnectionPtr &connection, const QString &objectPath,
+    RoomListChannel(const ConnectionPtr &connection, const QString &objectPath,
             const QVariantMap &immutableProperties);
 
 private:
@@ -1,4 +1,4 @@
-/* RoomList channel client-side proxy
+/* RoomListChannel channel client-side proxy
  *
  * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
-- 
1.5.6.5




More information about the telepathy-commits mailing list